@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2015 The University of Utah
+// Copyright (c) 2012, 2013, 2015, 2017, 2019 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -101,7 +101,6 @@ void CallExprToValue::HandleTranslationUnit(ASTContext &Ctx)
   }
 
   TransAssert(TheCallExpr && "NULL TheCallExpr!");
-  TransAssert(CurrentFD && "NULL CurrentFD");
 
   Ctx.getDiagnostics().setSuppressAllDiagnostics(false);
 
@@ -132,7 +131,12 @@ void CallExprToValue::replaceCallExpr(void)
     CommaStr = RVStr;
     RVQualType.getAsStringInternal(RVStr, Context->getPrintingPolicy());
     RVStr += ";\n";
-    RewriteHelper->insertStringBeforeFunc(CurrentFD, RVStr);
+    if (CurrentFD) {
+      RewriteHelper->insertStringBeforeFunc(CurrentFD, RVStr);
+    }
+    else {
+      TheRewriter.InsertTextBefore(TheCallExpr->getBeginLoc(), RVStr);
+    }
   }
   else {
     CommaStr = "0";
