@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2015 The University of Utah
+// Copyright (c) 2012, 2013, 2015, 2019 The University of Utah
 // Copyright (c) 2012 Konstantin Tokarev <annulen@yandex.ru>
 // All rights reserved.
 //
@@ -104,9 +104,14 @@ void RemoveEnumMemberValue::removeEnumValue()
 {
   SourceManager &SrcManager = TheRewriter.getSourceMgr();
   SourceRange Range = TheEnumConstantDecl->getInitExpr()->getSourceRange();
-  const char *Buf = SrcManager.getCharacterData(Range.getBegin());
+  SourceLocation StartLoc = Range.getBegin();
+  if (StartLoc.isMacroID()) {
+    Range = SrcManager.getExpansionRange(StartLoc).getAsRange();
+    StartLoc = SrcManager.getExpansionLoc(StartLoc);
+  }
+  const char *Buf = SrcManager.getCharacterData(StartLoc);
   int offset = getOffset(Buf, '=');
-  Range.setBegin(Range.getBegin().getLocWithOffset(offset));
+  Range.setBegin(StartLoc.getLocWithOffset(offset));
   TheRewriter.RemoveText(Range);
 }
 
