@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2015, 2016, 2017 The University of Utah
+// Copyright (c) 2012, 2013, 2015, 2016, 2017, 2019, 2020 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -348,12 +348,19 @@ bool RemoveNamespaceRewriteVisitor::VisitDeclRefExpr(DeclRefExpr *DRE)
   }
 
   const ValueDecl *OrigDecl = DRE->getDecl();
+
   if (isa<FunctionDecl>(OrigDecl) || isa<VarDecl>(OrigDecl) ||
       isa<EnumConstantDecl>(OrigDecl)) {
     std::string Name;
     if (ConsumerInstance->getNewName(OrigDecl, Name)) {
-      ConsumerInstance->TheRewriter.ReplaceText(DRE->getBeginLoc(),
-        OrigDecl->getNameAsString().size(), Name);
+      unsigned Len = OrigDecl->getNameAsString().size();
+      if (const FunctionDecl *FD = dyn_cast<FunctionDecl>(OrigDecl)) {
+        // handle user-defined literals
+        if (const IdentifierInfo *IdInfo = FD->getLiteralIdentifier()) {
+          Len = IdInfo->getLength();
+        }
+      }
+      ConsumerInstance->TheRewriter.ReplaceText(DRE->getBeginLoc(), Len, Name);
     }
   }
 
@@ -458,7 +465,7 @@ bool RemoveNamespaceRewriteVisitor::VisitDependentTemplateSpecializationTypeLoc(
   TransAssert(DTST && "Bad DependentTemplateSpecializationType!");
 
   const IdentifierInfo *IdInfo = DTST->getIdentifier();
-  std::string IdName = IdInfo->getName();
+  std::string IdName = IdInfo->getName().str();
   std::string Name;
 
   // FIXME:
@@ -707,7 +714,8 @@ void RemoveNamespace::rewriteNamedDecls(void)
 
     Decl::Kind K = D->getKind();
     switch (K) {
-    case Decl::Function: {
+    case Decl::Function:
+    case Decl::CXXMethod: {
       // Check replaceFunctionDecl in RewriteUtils.cpp for the reason that
       // we need a special case for FunctionDecl
       const FunctionDecl *FD = dyn_cast<FunctionDecl>(D);
@@ -786,7 +794,10 @@ void RemoveNamespace::handleOneUsingShadowDecl(const UsingShadowDecl *UD,
     return;
 
   std::string NewName;
-  const UsingDecl *D = UD->getUsingDecl();
+  const BaseUsingDecl *BD = UD->getIntroducer();
+  const UsingDecl *D = dyn_cast<UsingDecl>(BD);
+  if (!D)
+    return;
 
   NestedNameSpecifierLoc QualifierLoc = D->getQualifierLoc();
   NestedNameSpecifier *NNS = QualifierLoc.getNestedNameSpecifier();
@@ -929,7 +940,6 @@ void RemoveNamespace::handleOneNamedDecl(const NamedDecl *ND,
       return;
 
     std::string NewName = NamePrefix + NamespaceName;
-    const IdentifierInfo *IdInfo = ND->getIdentifier();
     NewName += "_";
 
     if ( const TemplateDecl *TD = dyn_cast<TemplateDecl>(ND) ) {
@@ -946,8 +956,21 @@ void RemoveNamespace::handleOneNamedDecl(const NamedDecl *ND,
         return;
     }
 
+    const IdentifierInfo *IdInfo = ND->getIdentifier();
+    bool IsUserLiteral = false;
+    if (!IdInfo) {
+      const FunctionDecl *FD = cast<FunctionDecl>(ND);
+      IdInfo = FD->getLiteralIdentifier();
+      if (IdInfo)
+        IsUserLiteral = true;
+    }
+
     TransAssert(IdInfo && "Invalid IdentifierInfo!");
     NewName += IdInfo->getName();
+    // Make sure we have valid suffix for user literals
+    if (IsUserLiteral && IdInfo->getName().startswith("_")) {
+      NewName = "_" + NewName;
+    }
     NamedDeclToNewName[ND] = NewName;
   }
 }
@@ -1001,27 +1024,40 @@ bool RemoveNamespace::handleOneNamespaceDecl(NamespaceDecl *ND)
 void RemoveNamespace::removeNamespace(const NamespaceDecl *ND)
 {
   // Remove the right brace first
-  SourceLocation StartLoc = ND->getRBraceLoc();
-  if (StartLoc.isValid())
-    TheRewriter.RemoveText(StartLoc, 1);
+  SourceLocation RBLoc = ND->getRBraceLoc();
+  if (RBLoc.isValid()) {
+    if (RBLoc.isMacroID()) {
+      TheRewriter.RemoveText(SrcManager->getExpansionRange(RBLoc).getAsRange());
+    }
+    else {
+      TheRewriter.RemoveText(RBLoc, 1);
+    }
+  }
 
   // Then remove name and the left brace
-  StartLoc = ND->getBeginLoc();
+  SourceLocation StartLoc = ND->getBeginLoc();
   TransAssert(StartLoc.isValid() && "Invalid Namespace LocStart!");
 
-  const char *StartBuf = SrcManager->getCharacterData(StartLoc);
-  SourceRange NDRange = ND->getSourceRange();
+  StartLoc = SrcManager->getFileLoc(StartLoc);
   SourceLocation EndLoc;
-  if (NDRange.isValid()) {
-    int RangeSize = TheRewriter.getRangeSize(NDRange);
-    TransAssert((RangeSize != -1) && "Bad Namespace Range!");
-    std::string NDStr(StartBuf, RangeSize);
-    size_t Pos = NDStr.find('{');
-    TransAssert((Pos != std::string::npos) && "Cannot find LBrace!");
-    EndLoc = StartLoc.getLocWithOffset(Pos);
+  if (ND->decls_empty()) {
+    EndLoc = SrcManager->getFileLoc(RBLoc);
   }
   else {
-    EndLoc = RewriteHelper->getEndLocationUntil(StartLoc, '{');
+    DeclContext::decl_iterator I = ND->decls_begin();
+    EndLoc = SrcManager->getFileLoc(dyn_cast<Decl>(*I)->getBeginLoc());
+  }
+
+  if (StartLoc != EndLoc) {
+    EndLoc = EndLoc.getLocWithOffset(-1);
+    SourceRange NewRange(StartLoc, EndLoc);
+    int RangeSize = TheRewriter.getRangeSize(NewRange);
+    TransAssert((RangeSize != -1) && "Bad Namespace Range!");
+    const char *StartBuf = SrcManager->getCharacterData(StartLoc);
+    std::string NDStr(StartBuf, RangeSize);
+    size_t Pos = NDStr.find('{');
+    if (Pos != std::string::npos) 
+      EndLoc = StartLoc.getLocWithOffset(Pos);
   }
 
   TheRewriter.RemoveText(SourceRange(StartLoc, EndLoc));
