@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -387,19 +387,19 @@ bool RemoveUnusedFunction::hasValidOuterLocStart(
 SourceLocation RemoveUnusedFunction::getFunctionOuterLocStart(
                  const FunctionDecl *FD)
 {
-  SourceLocation LocStart = FD->getLocStart();
+  SourceLocation LocStart = FD->getBeginLoc();
   bool RecordLoc = false;
 
   // check if FD is from a function template
   if (FunctionTemplateDecl *FTD = FD->getDescribedFunctionTemplate()) {
-    // get FTD->getLocStart() only if it is less than FD->getLocStart,
+    // get FTD->getBeginLoc() only if it is less than FD->getBeginLoc,
     // for example, in the code below:
     //   template <typename T> struct S {template <typename T1> void foo();};
     //   template<typename T> template<typename T1> void S<T>::foo() { }
     // where
-    //   FTD->getLocStart() points to the begining of "template<typename T1>"
+    //   FTD->getBeginLoc() points to the begining of "template<typename T1>"
     if (hasValidOuterLocStart(FTD, FD)) {
-      LocStart = FTD->getLocStart();
+      LocStart = FTD->getBeginLoc();
       RecordLoc = true;
     }
   }
@@ -459,13 +459,8 @@ SourceLocation RemoveUnusedFunction::getFunctionLocEnd(
     FDLoc = SrcManager->getExpansionLoc(FDLoc);
   const char * const FDBuf = SrcManager->getCharacterData(FDLoc);
   const char * LocEndBuf = SrcManager->getCharacterData(LocEnd);
-  if ((FDBuf < LocEndBuf) && !isTokenOperator(FDLoc))
-    return LocEnd;
-  std::string Str;
-  RewriteHelper->getStringBetweenLocs(Str, LocStart, LocEnd);
-  if (Str.find("friend ") == std::string::npos &&
-      Str.find("friend\t") == std::string::npos &&
-      Str.find("friend\n") == std::string::npos)
+  if ((FDBuf < LocEndBuf) && !isTokenOperator(FDLoc) &&
+      !FD->isDeleted() && !FD->isDefaulted())
     return LocEnd;
   int Offset = 0;
   while (*LocEndBuf != ';') {
@@ -530,6 +525,10 @@ void RemoveUnusedFunction::removeOneExplicitInstantiation(
   const char * const FileStartBuf = SrcManager->getCharacterData(FileStartLoc);
 
   SourceLocation Loc = Spec->getPointOfInstantiation();
+  if (Loc.isInvalid()) {
+    TheRewriter.RemoveText(Spec->getSourceRange());
+    return;
+  }
   const char *OrigStartBuf = SrcManager->getCharacterData(Loc);
   const char *StartBuf = OrigStartBuf;
   int Offset = 0;
@@ -699,11 +698,14 @@ RemoveUnusedFunction::lookupFunctionDeclShallow(const DeclarationName &DName,
     }
   }
 
+  bool InNamespace = Ctx->isNamespace();
   for (auto *I : Ctx->using_directives()) {
     const NamespaceDecl *ND = I->getNominatedNamespace();
     // avoid infinite recursion
-    if (ND->getLookupParent() == Ctx)
+    if ((InNamespace && dyn_cast<NamespaceDecl>(Ctx) == ND) ||
+        ND->getLookupParent() == Ctx) {
       return NULL;
+    }
     if (const FunctionDecl *FD = lookupFunctionDeclShallow(DName, ND))
       return FD;
   }
