@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015, 2016 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2019, 2020 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -110,9 +110,7 @@ bool RenameParamVisitor::VisitFunctionDecl(FunctionDecl *FD)
 
     ConsumerInstance->RewriteHelper->replaceVarDeclName(PD, TmpSS.str());
 
-    if (FD->isThisDeclarationADefinition()) {
-      ParamNameMap[*I] = TmpSS.str();
-    }
+    ParamNameMap[*I] = TmpSS.str();
   }
   return true;
 }
@@ -129,7 +127,8 @@ bool RenameParamVisitor::VisitDeclRefExpr(DeclRefExpr *DRE)
 
   llvm::DenseMap<ParmVarDecl *, std::string>::iterator I =
     ParamNameMap.find(PD);
-  TransAssert((I != ParamNameMap.end()) && "Bad Param!");
+  if (I == ParamNameMap.end())
+    return true;
   
   return ConsumerInstance->RewriteHelper->replaceExpr(DRE, (*I).second);
 }
@@ -272,10 +271,8 @@ unsigned int RenameParam::validatePostfix(FunctionDecl *FD,
 
 RenameParam::~RenameParam(void)
 {
-  if (VarCollectionVisitor)
-    delete VarCollectionVisitor;
-  if (RenameVisitor)
-    delete RenameVisitor;
+  delete VarCollectionVisitor;
+  delete RenameVisitor;
 
   for (llvm::DenseMap<FunctionDecl *, ExistingNumberSet *>::iterator 
         I = FunExistingVarsMap.begin(), E = FunExistingVarsMap.end();
