@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2018 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -57,6 +57,19 @@ void RewriteUtils::Finalize(void)
   }
 }
 
+SourceLocation RewriteUtils::getRealLocation(SourceLocation Loc) {
+  if (Loc.isMacroID()) {
+    return SrcManager->getExpansionLoc(Loc);
+  }
+  return Loc;
+}
+
+SourceRange RewriteUtils::getRealSourceRange(SourceRange Range) {
+  SourceLocation StartLoc = Range.getBegin();
+  SourceLocation EndLoc = Range.getEnd();
+  return SourceRange(getRealLocation(StartLoc), getRealLocation(EndLoc));
+}
+
 // copied from Rewriter.cpp
 unsigned RewriteUtils::getLocationOffsetAndFileID(SourceLocation Loc,
                                                   FileID &FID,
@@ -663,11 +676,12 @@ bool RewriteUtils::replaceExpr(const Expr *E,
   int RangeSize = TheRewriter->getRangeSize(ExprRange);
   if (RangeSize == -1) {
     SourceLocation StartLoc = ExprRange.getBegin();
-    if (!SrcManager->isMacroBodyExpansion(StartLoc))
-      return false;
-    StartLoc = SrcManager->getFileLoc(StartLoc);
+    if (SrcManager->isMacroBodyExpansion(StartLoc)) {
+      StartLoc = SrcManager->getFileLoc(StartLoc);
+    }
     SourceLocation EndLoc = ExprRange.getEnd();
-    if (SrcManager->isMacroBodyExpansion(EndLoc)) {
+    if (SrcManager->isMacroBodyExpansion(EndLoc) ||
+        SrcManager->isMacroArgExpansion(EndLoc)) {
       // FIXME: handle cases below:
       // #define macro bar(1,2);
       // int bar(int p1, int p2) { return p1 + p2; }
@@ -1329,8 +1343,13 @@ bool RewriteUtils::removeVarDecl(const VarDecl *VD,
     TransAssert(FirstVD && "Invalid Var Decl!");
     if (VD == FirstVD) {
       SourceLocation StartLoc = VD->getLocation();
-      SourceLocation EndLoc = 
-        getEndLocationUntil(VarRange, ',');
+      SourceLocation EndLoc;
+      if (I + 1 == DGR.end()) {
+        EndLoc = StartLoc;
+      }
+      else {
+        EndLoc = getEndLocationUntil(VarRange, ',');
+      }
 
       return !(TheRewriter->RemoveText(SourceRange(StartLoc, EndLoc)));
     }
@@ -1421,13 +1440,13 @@ bool RewriteUtils::removeIfAndCond(const IfStmt *IS)
   const Stmt *ThenStmt = IS->getThen();
   TransAssert(ThenStmt && "NULL ThenStmt!");
 
-  SourceLocation ThenLoc = ThenStmt->getBeginLoc();
+  SourceLocation ThenLoc = getRealLocation(ThenStmt->getBeginLoc());
   SourceLocation EndLoc =  ThenLoc.getLocWithOffset(-1);
 
   Rewriter::RewriteOptions Opts;
   // We don't want to include the previously inserted string
   Opts.IncludeInsertsAtBeginOfRange = false;
-  return !TheRewriter->RemoveText(SourceRange(IfLoc, EndLoc), Opts);
+  return !TheRewriter->RemoveText(SourceRange(getRealLocation(IfLoc), EndLoc), Opts);
 }
 
 bool RewriteUtils::removeArraySubscriptExpr(const Expr *E)
@@ -1489,7 +1508,14 @@ bool RewriteUtils::replaceFunctionDefWithStr(const FunctionDecl *FD,
 {
   const Stmt *Body = FD->getBody();
   TransAssert(Body && "FunctionDecl is not a definition!");
-  return !TheRewriter->ReplaceText(Body->getSourceRange(), Str);
+  SourceRange Range = Body->getSourceRange();
+  SourceLocation StartLoc = Range.getBegin();
+  if (StartLoc.isMacroID())
+    StartLoc = SrcManager->getExpansionLoc(StartLoc);
+  SourceLocation EndLoc = Range.getEnd();
+  if (EndLoc.isMacroID())
+    EndLoc = SrcManager->getExpansionLoc(EndLoc);
+  return !TheRewriter->ReplaceText(SourceRange(StartLoc, EndLoc), Str);
 }
 
 // FIXME: probably we don't need this function, because we could use 
