@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -357,7 +357,7 @@ unsigned int Transformation::getConstArraySize(
   llvm::SmallString<8> IntStr;
   Result.toStringUnsigned(IntStr);
 
-  std::stringstream TmpSS(IntStr.str());
+  std::stringstream TmpSS(IntStr.str().str());
 
   if (!(TmpSS >> Sz)) {
     TransAssert(0 && "Non-integer value!");
@@ -1066,6 +1066,7 @@ unsigned Transformation::getNumExplicitDecls(const CXXRecordDecl *CXXRD)
 
 bool Transformation::isInIncludedFile(SourceLocation Loc) const
 {
+  Loc = getRealLocation(Loc);
   return SrcManager->getFileID(Loc) != SrcManager->getMainFileID();
 }
 
@@ -1079,6 +1080,13 @@ bool Transformation::isInIncludedFile(const Stmt *S) const
   return isInIncludedFile(S->getBeginLoc());
 }
 
+SourceLocation Transformation::getRealLocation(SourceLocation Loc) const
+{
+  if (Loc.isMacroID())
+    return SrcManager->getExpansionLoc(Loc);
+  return Loc;
+}
+
 bool Transformation::isDeclaringRecordDecl(const RecordDecl *RD)
 {
   SourceLocation SemiLoc =
