@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014, 2015 2016 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015, 2016, 2018, 2019 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -301,6 +301,10 @@ protected:
 
   bool isDeclaringRecordDecl(const clang::RecordDecl *RD);
 
+  // If the location is a MacroID, get its expansion location.
+  // Otherwise, just return the location.
+  clang::SourceLocation getRealLocation(clang::SourceLocation Loc) const;
+
   const std::string Name;
 
   int TransformationCounter;
